@@ -54,8 +54,7 @@ def nostdout():
 
 
 def bader():
-    splash = f"""
-      Bader Charge Analysis ({__version__})
+    splash = f"""\n  Bader Charge Analysis ({__version__})
     """
 
     # source avail configs
@@ -198,7 +197,7 @@ def bader():
         config['fortran_format'] += args['fortran_format']
         config['fortran_format'] %= 3
     if args.get('prefix') is not None and args.get('prefix'):
-        config['prefix'] = args['prefix'][0]
+        config['prefix'] = args['prefix']
     if args.get('output') is not None:
         config['output'] = args['output'][0]
 
